{% extends "tcms_base.html" %} {% load static %} {% block subtitle %}Case History{% endblock %} {% block custom_stylesheet %} {% endblock %} {% block custom_javascript %}
{% endblock %} {% block contents %}
Home >> ... {% if testplan %} >> {{ testplan.plan_id }}: {{ testplan.name }} {% endif %} >> {{ testcase.case_id }}: {{ testcase.summary }} >> View edit history

## Test Case History

Text Version | Modified Date | Changed By
--- | --- | ---
{% for text in test_case_texts %}
{{ text.case_text_version }} | {{ text.create_date }} | {{ text.author__email }}
{% if text.case_text_version == select_case_text_version %}
{% for text in text_to_show %} SETUP: {{ text.setup|safe }} ACTION: {{ text.action|safe }} EXPECTED RESULT: {{ text.effect|safe }} BREAKDOWN: {{ text.breakdown|safe }} {% endfor %}
{% endif %} {% endfor %}

{% endblock %}